mylog: My logarithm function

Description Usage Arguments Value Examples

View source: R/mylog.R

Description

My logarithm function

Usage

1
mylog(x)

Arguments

x

is a vector of numerical values that need to be converted into log

Value

a vector with the same length as x with logged values of x

Examples

1
2
log(1)
mylog(1)

IrisGanser/mypkg_Iris documentation built on Oct. 30, 2019, 7:24 p.m.